@@ -1,15 +1,16 @@
 import math
+import urllib.parse
 
 from .common import InfoExtractor
-from ..compat import (
-    compat_urllib_parse_urlparse,
-    compat_parse_qs,
-)
 from ..utils import (
-    format_field,
     InAdvancePagedList,
+    determine_ext,
+    format_field,
+    int_or_none,
+    join_nonempty,
     traverse_obj,
     unified_timestamp,
+    url_or_none,
 )
 
 
@@ -20,8 +21,8 @@ class BanByeBaseIE(InfoExtractor):
 
     @staticmethod
     def _extract_playlist_id(url, param='playlist'):
-        return compat_parse_qs(
-            compat_urllib_parse_urlparse(url).query).get(param, [None])[0]
+        return urllib.parse.parse_qs(
+            urllib.parse.urlparse(url).query).get(param, [None])[0]
 
     def _extract_playlist(self, playlist_id):
         data = self._download_json(f'{self._API_BASE}/playlists/{playlist_id}', playlist_id)
@@ -33,6 +34,7 @@ class BanByeBaseIE(InfoExtractor):
 class BanByeIE(BanByeBaseIE):
     _VALID_URL = r'https?://(?:www\.)?banbye\.com/(?:en/)?watch/(?P<id>[\w-]+)'
     _TESTS = [{
+        # ['src']['mp4']['levels'] direct mp4 urls only
         'url': 'https://banbye.com/watch/v_ytfmvkVYLE8T',
         'md5': '2f4ea15c5ca259a73d909b2cfd558eb5',
         'info_dict': {
@@ -61,6 +63,7 @@ class BanByeIE(BanByeBaseIE):
         },
         'playlist_mincount': 9,
     }, {
+        # ['src']['mp4']['levels'] direct mp4 urls only
         'url': 'https://banbye.com/watch/v_kb6_o1Kyq-CD',
         'info_dict': {
             'id': 'v_kb6_o1Kyq-CD',
@@ -80,6 +83,48 @@ class BanByeIE(BanByeBaseIE):
             'view_count': int,
             'comment_count': int,
         },
+    }, {
+        # ['src']['hls']['levels'] variant m3u8 urls only; master m3u8 is 404
+        'url': 'https://banbye.com/watch/v_a_gPFuC9LoW5',
+        'info_dict': {
+            'id': 'v_a_gPFuC9LoW5',
+            'ext': 'mp4',
+            'title': 'md5:183524056bebdfa245fd6d214f63c0fe',
+            'description': 'md5:943ac87287ca98d28d8b8797719827c6',
+            'uploader': 'wRealu24',
+            'channel_id': 'ch_wrealu24',
+            'channel_url': 'https://banbye.com/channel/ch_wrealu24',
+            'upload_date': '20231113',
+            'timestamp': 1699874062,
+            'view_count': int,
+            'like_count': int,
+            'dislike_count': int,
+            'comment_count': int,
+            'thumbnail': 'https://cdn.banbye.com/video/v_a_gPFuC9LoW5/96.webp',
+            'tags': ['jaszczur', 'sejm', 'lewica', 'polska', 'ukrainizacja', 'pierwszeposiedzeniesejmu'],
+        },
+        'expected_warnings': ['Failed to download m3u8'],
+    }, {
+        # ['src']['hls']['masterPlaylist'] m3u8 only
+        'url': 'https://banbye.com/watch/v_B0rsKWsr-aaa',
+        'info_dict': {
+            'id': 'v_B0rsKWsr-aaa',
+            'ext': 'mp4',
+            'title': 'md5:00b254164b82101b3f9e5326037447ed',
+            'description': 'md5:3fd8b48aa81954ba024bc60f5de6e167',
+            'uploader': 'PSTV Piotr Szlachtowicz ',
+            'channel_id': 'ch_KV9EVObkB9wB',
+            'channel_url': 'https://banbye.com/channel/ch_KV9EVObkB9wB',
+            'upload_date': '20240629',
+            'timestamp': 1719646816,
+            'duration': 2377,
+            'view_count': int,
+            'like_count': int,
+            'dislike_count': int,
+            'comment_count': int,
+            'thumbnail': 'https://cdn.banbye.com/video/v_B0rsKWsr-aaa/96.webp',
+            'tags': ['Biden', 'Trump', 'Wybory', 'USA'],
+        },
     }]
 
     def _real_extract(self, url):
@@ -94,11 +139,24 @@ class BanByeIE(BanByeBaseIE):
             'id': f'{quality}p',
             'url': f'{self._CDN_BASE}/video/{video_id}/{quality}.webp',
         } for quality in [48, 96, 144, 240, 512, 1080]]
-        formats = [{
-            'format_id': f'http-{quality}p',
-            'quality': quality,
-            'url': f'{self._CDN_BASE}/video/{video_id}/{quality}.mp4',
-        } for quality in data['quality']]
+
+        formats = []
+        url_data = self._download_json(f'{self._API_BASE}/videos/{video_id}/url', video_id, data=b'')
+        if master_url := traverse_obj(url_data, ('src', 'hls', 'masterPlaylist', {url_or_none})):
+            formats = self._extract_m3u8_formats(master_url, video_id, 'mp4', m3u8_id='hls', fatal=False)
+
+        for format_id, format_url in traverse_obj(url_data, (
+                'src', ('mp4', 'hls'), 'levels', {dict.items}, lambda _, v: url_or_none(v[1]))):
+            ext = determine_ext(format_url)
+            is_hls = ext == 'm3u8'
+            formats.append({
+                'url': format_url,
+                'ext': 'mp4' if is_hls else ext,
+                'format_id': join_nonempty(is_hls and 'hls', format_id),
+                'protocol': 'm3u8_native' if is_hls else 'https',
+                'height': int_or_none(format_id),
+            })
+        self._remove_duplicate_formats(formats)
 
         return {
             'id': video_id,
@@ -152,7 +210,7 @@ class BanByeChannelIE(BanByeBaseIE):
                 'sort': 'new',
                 'limit': self._PAGE_SIZE,
                 'offset': page_num * self._PAGE_SIZE,
-            }, note=f'Downloading page {page_num+1}')
+            }, note=f'Downloading page {page_num + 1}')
             return [
                 self.url_result(f"{self._VIDEO_BASE}/{video['_id']}", BanByeIE)
                 for video in data['items']
