@@ -1,5 +1,4 @@
 from .common import InfoExtractor
-from ..compat import compat_str
 from ..utils import (
     format_field,
     int_or_none,
@@ -23,9 +22,19 @@ class JojIE(InfoExtractor):
             'id': 'a388ec4c-6019-4a4a-9312-b1bee194e932',
             'ext': 'mp4',
             'title': 'NOVÉ BÝVANIE',
-            'thumbnail': r're:^https?://.*\.jpg$',
+            'thumbnail': r're:^https?://.*?$',
             'duration': 3118,
-        }
+        },
+    }, {
+        'url': 'https://media.joj.sk/embed/CSM0Na0l0p1',
+        'info_dict': {
+            'id': 'CSM0Na0l0p1',
+            'ext': 'mp4',
+            'height': 576,
+            'title': 'Extrémne rodiny 2 - POKRAČOVANIE (2012/04/09 21:30:00)',
+            'duration': 3937,
+            'thumbnail': r're:^https?://.*?$',
+        },
     }, {
         'url': 'https://media.joj.sk/embed/9i1cxv',
         'only_matching': True,
@@ -41,12 +50,12 @@ class JojIE(InfoExtractor):
         video_id = self._match_id(url)
 
         webpage = self._download_webpage(
-            'https://media.joj.sk/embed/%s' % video_id, video_id)
+            f'https://media.joj.sk/embed/{video_id}', video_id)
 
-        title = self._search_regex(
-            (r'videoTitle\s*:\s*(["\'])(?P<title>(?:(?!\1).)+)\1',
-             r'<title>(?P<title>[^<]+)'), webpage, 'title',
-            default=None, group='title') or self._og_search_title(webpage)
+        title = (self._search_json(r'videoTitle\s*:', webpage, 'title', video_id,
+                                   contains_pattern=r'["\'].+["\']', default=None)
+                 or self._html_extract_title(webpage, default=None)
+                 or self._og_search_title(webpage))
 
         bitrates = self._parse_json(
             self._search_regex(
@@ -56,17 +65,19 @@ class JojIE(InfoExtractor):
 
         formats = []
         for format_url in try_get(bitrates, lambda x: x['mp4'], list) or []:
-            if isinstance(format_url, compat_str):
+            if isinstance(format_url, str):
                 height = self._search_regex(
-                    r'(\d+)[pP]\.', format_url, 'height', default=None)
+                    r'(\d+)[pP]|(pal)\.', format_url, 'height', default=None)
+                if height == 'pal':
+                    height = 576
                 formats.append({
                     'url': format_url,
                     'format_id': format_field(height, None, '%sp'),
-                    'height': int(height),
+                    'height': int_or_none(height),
                 })
         if not formats:
             playlist = self._download_xml(
-                'https://media.joj.sk/services/Video.php?clip=%s' % video_id,
+                f'https://media.joj.sk/services/Video.php?clip={video_id}',
                 video_id)
             for file_el in playlist.findall('./files/file'):
                 path = file_el.get('path')
@@ -74,14 +85,13 @@ class JojIE(InfoExtractor):
                     continue
                 format_id = file_el.get('id') or file_el.get('label')
                 formats.append({
-                    'url': 'http://n16.joj.sk/storage/%s' % path.replace(
-                        'dat/', '', 1),
+                    'url': 'http://n16.joj.sk/storage/{}'.format(path.replace(
+                        'dat/', '', 1)),
                     'format_id': format_id,
                     'height': int_or_none(self._search_regex(
                         r'(\d+)[pP]', format_id or path, 'height',
                         default=None)),
                 })
-        self._sort_formats(formats)
 
         thumbnail = self._og_search_thumbnail(webpage)
 
