@@ -8,10 +8,10 @@ from ..utils import (
     get_element_html_by_class,
     get_element_text_and_html_by_tag,
     int_or_none,
-    unified_strdate,
     strip_or_none,
     traverse_obj,
     try_call,
+    unified_strdate,
 )
 
 
@@ -27,7 +27,7 @@ class MonstercatIE(InfoExtractor):
             'release_date': '20230711',
             'album': 'The Secret Language of Trees',
             'album_artist': 'BT',
-        }
+        },
     }]
 
     def _extract_tracks(self, table, album_meta):
@@ -41,7 +41,7 @@ class MonstercatIE(InfoExtractor):
             track_number = int_or_none(try_call(lambda: get_element_by_class('py-xsmall', td)))
             if not track_id or not release_id:
                 self.report_warning(f'Skipping track {track_number}, ID(s) not found')
-                self.write_debug(f'release_id={repr(release_id)} track_id={repr(track_id)}')
+                self.write_debug(f'release_id={release_id!r} track_id={track_id!r}')
                 continue
             yield {
                 **album_meta,
@@ -51,7 +51,7 @@ class MonstercatIE(InfoExtractor):
                 'artist': clean_html(try_call(lambda: get_element_by_class('d-block fs-xxsmall', td))),
                 'url': f'https://www.monstercat.com/api/release/{release_id}/track-stream/{track_id}',
                 'id': track_id,
-                'ext': 'mp3'
+                'ext': 'mp3',
             }
 
     def _real_extract(self, url):
